@@ -1,6 +1,6 @@
+from questionary import Choice
+
 from .validator import (
-    DateValidator,
-    EnvironmentValidator,
     KeywordValidator,
     PhoneValidator,
     SimpleEmailValidator,
@@ -9,15 +9,9 @@ from .validator import (
 
 available_pipelines = ["data-copy", "csv-to-parquet"]
 boilerplate_questions = [
-    {
-        "type": "text",
-        "name": "id",
-        "message": "Kjøremiljø ID (Som gitt til deg av Origo)",
-        "validate": EnvironmentValidator,
-    },
     {"type": "text", "name": "title", "message": "Tittel", "validate": TitleValidator},
     {"type": "text", "name": "description", "message": "Beskrivelse"},
-    {"type": "text", "name": "objective", "message": "Objektiv"},
+    {"type": "text", "name": "objective", "message": "Formål"},
     {
         "type": "text",
         "name": "keywords",
@@ -27,14 +21,12 @@ boilerplate_questions = [
     {
         "type": "select",
         "name": "accessRights",
-        "message": "Tilgang",
-        "choices": ["non-public", "public", "restricted"],
-    },
-    {
-        "type": "select",
-        "name": "confidentiality",
-        "message": "Nivå",
-        "choices": ["green", "yellow", "red", "purple"],
+        "message": "Tilgangsnivå",
+        "choices": [
+            Choice("Offentlig", "public"),
+            Choice("Begrenset offentlighet", "restricted"),
+            Choice("Unntatt offentlighet", "non-public"),
+        ],
     },
     {"type": "text", "name": "name", "message": "Kontaktperson - navn"},
     {
@@ -56,16 +48,4 @@ boilerplate_questions = [
         "message": "Prosessering",
         "choices": available_pipelines,
     },
-    {
-        "type": "text",
-        "name": "startTime",
-        "message": "Start tidspunkt for datasett",
-        "validate": DateValidator,
-    },
-    {
-        "type": "text",
-        "name": "endTime",
-        "message": "Slutt tidspunkt for datasett",
-        "validate": DateValidator,
-    },
 ]
